@@ -1,8 +1,21 @@
 from __future__ import division, print_function # confidence high
 
-from stsci.tools import parseinput, fileutil
+import astropy
+from stsci.tools import parseinput, fileutil, convertwaiveredfits, readgeis
 from astropy.io import fits
 import os
+import sys
+
+from distutils.version import LooseVersion
+
+PY3K = sys.version_info[0] > 2
+if PY3K:
+    string_types = str
+else:
+    string_types = basestring
+
+ASTROPY_VER_GE13 = LooseVersion(astropy.__version__) >= LooseVersion('1.3')
+
 
 def checkFiles(filelist,ivmlist = None):
     """
@@ -15,13 +28,14 @@ def checkFiles(filelist,ivmlist = None):
 
     The list of science files should match the list of ivm files at the end.
     """
-
+    toclose = False
+    if isinstance(filelist[0], str):
+        toclose = True
     newfilelist, ivmlist = checkFITSFormat(filelist, ivmlist)
 
     # check for STIS association files. This must be done before
     # the other checks in order to handle correctly stis
     # assoc files
-    #if fits.getval(newfilelist[0], 'INSTRUME') == 'STIS':
     newfilelist, ivmlist = checkStisFiles(newfilelist, ivmlist)
     if newfilelist == []:
         return [], []
@@ -43,6 +57,8 @@ def checkFiles(filelist,ivmlist = None):
     if newfilelist == []:
         return [], []
 
+    if toclose:
+        newfilelist = [hdul.filename() for hdul in newfilelist]
     return newfilelist, ivmlist
 
 def checkFITSFormat(filelist, ivmlist=None):
@@ -82,9 +98,12 @@ def checkStisFiles(filelist, ivmlist=None):
         errormsg += "Quitting ...\n"
         raise ValueError(errormsg)
 
+    toclose = False
     for t in zip(filelist, ivmlist):
-
-        if fits.getval(t[0], 'INSTRUME') != 'STIS':
+        if isinstance(t[0], str):
+            t = (fits.open(t[0]), t[1])
+            toclose = True
+        if t[0][0].header['INSTRUME'] != 'STIS':
             newflist.append(t[0])
             newilist.append(t[1])
             continue
@@ -92,8 +111,10 @@ def checkStisFiles(filelist, ivmlist=None):
             removed_files.append(t[0])
             continue
         sci_count = stisObsCount(t[0])
+        stisExt2PrimKw([t[0]])
         if sci_count >1:
             newfilenames = splitStis(t[0], sci_count)
+
             assoc_files.extend(newfilenames)
             removed_files.append(t[0])
             if (isinstance(t[1], tuple) and t[1][0] is not None) or \
@@ -109,8 +130,8 @@ def checkStisFiles(filelist, ivmlist=None):
             errormsg = "No valid 'SCI extension in STIS file\n"
             raise ValueError(errormsg)
 
-        stisExt2PrimKw([t[0]])
-
+        if toclose:
+            t[0].close()
     newflist.extend(assoc_files)
     newilist.extend(assoc_ilist)
     return newflist, newilist
@@ -119,10 +140,15 @@ def check_exptime(filelist):
     """
     Removes files with EXPTIME==0 from filelist.
     """
+    toclose = False
     removed_files = []
     for f in filelist:
+        if isinstance(f, str):
+            f = fits.open(f)
+            toclose = True
+
         try:
-            exptime = fileutil.getHeader(f+'[sci,1]')['EXPTIME']
+            exptime = f[0].header['EXPTIME']
         except KeyError:
             removed_files.append(f)
             print("Warning:  There are files without keyword EXPTIME")
@@ -134,7 +160,7 @@ def check_exptime(filelist):
     if removed_files != []:
         print("Warning:  Removing the following files from input list")
         for f in removed_files:
-            print('\t',f)
+            print('\t',f.filename() or "")
     return removed_files
 
 def checkNGOODPIX(filelist):
@@ -146,25 +172,31 @@ def checkNGOODPIX(filelist):
     WFPC2 c1f.fits arrays and NICMOS DQ arrays will need to be
     done separately (and later).
     """
+    toclose = False
     removed_files = []
     supported_instruments = ['ACS','STIS','WFC3']
     for inputfile in filelist:
-        if fileutil.getKeyword(inputfile,'instrume') in supported_instruments:
-            file = fits.open(inputfile)
-            ngood = 0
-            for extn in file:
-                if 'EXTNAME' in extn.header and extn.header['EXTNAME'] == 'SCI':
-                    ngood += extn.header['NGOODPIX']
-            file.close()
+        if isinstance(inputfile, str):
+            if fileutil.getKeyword(inputfile,'instrume') in supported_instruments:
+                inputfile = fits.open(inputfile)
+                toclose = True
+        elif inputfile[0].header['instrume'] not in supported_instruments:
+            continue
 
-            if (ngood == 0):
-                removed_files.append(inputfile)
+        ngood = 0
+        for extn in inputfile:
+            if 'EXTNAME' in extn.header and extn.header['EXTNAME'] == 'SCI':
+                ngood += extn.header['NGOODPIX']
+        if (ngood == 0):
+            removed_files.append(inputfile)
+        if toclose:
+            inputfile.close()
 
     if removed_files != []:
         print("Warning:  Files without valid pixels detected: keyword NGOODPIX = 0.0")
         print("Warning:  Removing the following files from input list")
         for f in removed_files:
-            print('\t',f)
+            print('\t',f.filename() or "")
 
     return removed_files
 
@@ -192,17 +224,21 @@ def stisObsCount(input):
     Output: Number of stis science extensions in input
     """
     count = 0
-    f = fits.open(input)
-    for ext in f:
+    toclose = False
+    if isinstance(input, str):
+        input = fits.open(input)
+        toclose = True
+    for ext in input:
         if 'extname' in ext.header:
             if (ext.header['extname'].upper() == 'SCI'):
                 count += 1
-    f.close()
+    if toclose:
+        input.close()
     return count
 
 def splitStis(stisfile, sci_count):
     """
-    :Purpose: Split a STIS association file into multiple imset MEF files.
+    Split a STIS association file into multiple imset MEF files.
 
     Split the corresponding spt file if present into single spt files.
     If an spt file can't be split or is missing a Warning is printed.
@@ -215,9 +251,14 @@ def splitStis(stisfile, sci_count):
     """
     newfiles = []
 
-    f = fits.open(stisfile)
+    toclose = False
+    if isinstance(stisfile, str):
+        f = fits.open(stisfile)
+        toclose = True
+    else:
+        f = stisfile
     hdu0 = f[0].copy()
-
+    stisfilename = stisfile.filename()
 
     for count in range(1,sci_count+1):
         fitsobj = fits.HDUList()
@@ -242,6 +283,7 @@ def splitStis(stisfile, sci_count):
             fitsobj[1].header['EXTVER'] = 1
             fitsobj[2].header['EXTVER'] = 1
             fitsobj[3].header['EXTVER'] = 1
+
         except ValueError:
             print('\nWarning:')
             print('Extension version %d of the input file %s does not' %(count, stisfile))
@@ -259,10 +301,14 @@ def splitStis(stisfile, sci_count):
 
             # Write out the new file
         fitsobj.writeto(newfilename)
-        newfiles.append(newfilename)
+        # Insure returned HDUList is associated with a file
+        fitsobj.close()
+        fitsobj = fits.open(newfilename, mode='update')
+        newfiles.append(fitsobj) # Return HDUList, not filename
+
     f.close()
 
-    sptfilename = fileutil.buildNewRootname(stisfile, extn='_spt.fits')
+    sptfilename = fileutil.buildNewRootname(stisfilename, extn='_spt.fits')
     try:
         sptfile = fits.open(sptfilename)
     except IOError:
@@ -288,13 +334,14 @@ def splitStis(stisfile, sci_count):
                 fitsobj.writeto(newfilename)
         except:
             print("Warning: Unable to split spt file %s " % sptfilename)
-        sptfile.close()
+        if toclose:
+            sptfile.close()
 
     return newfiles
 
 def stisExt2PrimKw(stisfiles):
     """
-        Several kw which are usuall yin the primary header
+        Several kw which are usually in the primary header
         are in the extension header for STIS. They are copied to
         the primary header for convenience.
         List if kw:
@@ -304,17 +351,24 @@ def stisExt2PrimKw(stisfiles):
     kw_list = ['DATE-OBS', 'EXPEND', 'EXPSTART', 'EXPTIME']
 
     for sfile in stisfiles:
-        d = {}
-        for k in kw_list:
-            d[k] = fits.getval(sfile, k, ext=1)
+        toclose = False
 
-        for item in d.items():
-            fits.setval(sfile, item[0], value=item[1], comment='Copied from extension header')
+        if isinstance(sfile, str):
+            sfile = fits.open(sfile, mode='update')
+            toclose = True
+
+        #d = {}
+        for k in kw_list:
+            sfile[0].header[k] = sfile[1].header[k]
+            sfile[0].header.comments[k] = "Copied from extension header"
+        if toclose:
+            sfile.close()
 
 
 def isSTISSpectroscopic(fname):
 
-    if fits.getval(fname, 'OBSTYPE') == 'SPECTROSCOPIC':
+    if (isinstance(fname, fits.HDUList) and fname[0].header['OBSTYPE'] == 'SPECTROSCOPIC'
+        or isinstance(fname, str) and fits.getval(fname, 'OBSTYPE') == 'SPECTROSCOPIC'):
         print("Warning:  STIS spectroscopic files detected")
         print("Warning:  Removing %s from input list" % fname)
         return True
@@ -324,21 +378,27 @@ def isSTISSpectroscopic(fname):
 def checkPA_V3(fnames):
     removed_files = []
     for f in fnames:
+        toclose = False
+        if isinstance(f, str):
+            f = fits.open(f)
+            toclose = True
         try:
-            pav3 = fits.getval(f, 'PA_V3')
+            pav3 = f[0].header['PA_V3']
         except KeyError:
-            rootname = fits.getval(f, 'ROOTNAME')
+            rootname = f[0].header['ROOTNAME']
             sptfile = rootname+'_spt.fits'
             if fileutil.findFile(sptfile):
                 try:
                     pav3 = fits.getval(sptfile, 'PA_V3')
                 except KeyError:
                     print("Warning:  Files without keyword PA_V3 detected")
-                    removed_files.append(f)
-                fits.setval(f, 'PA_V3', value=pav3)
+                    removed_files.append(f.filename() or "")
+                f[0].header['PA_V3'] = pav3
             else:
                 print("Warning:  Files without keyword PA_V3 detected")
-                removed_files.append(f)
+                removed_files.append(f.filename() or "")
+        if toclose:
+            f.close()
     if removed_files != []:
         print("Warning:  Removing the following files from input list")
         for f in removed_files:
@@ -391,7 +451,7 @@ def convert2fits(sci_ivm):
 
     return removed_files, translated_names, newivmlist
 
-def waiver2mef(sciname, newname=None, convert_dq=True):
+def waiver2mef(sciname, newname=None, convert_dq=True, writefits=True):
     """
     Converts a GEIS science file and its corresponding
     data quality file (if present) to MEF format
@@ -399,23 +459,55 @@ def waiver2mef(sciname, newname=None, convert_dq=True):
     Returns the new name of the science image.
     """
 
-    def convert(file):
-        newfilename = fileutil.buildNewRootname(file, extn='_c0h.fits')
-        try:
-            newimage = fileutil.openImage(file,writefits=True,
-                                          fitsname=newfilename,clobber=True)
-            del newimage
-            return newfilename
-        except IOError:
-            print('Warning: File %s could not be found' % file)
-            return None
+    if isinstance(sciname, fits.HDUList):
+        filename = sciname.filename()
+    else:
+        filename = sciname
 
-    newsciname = convert(sciname)
-    if convert_dq:
-        dq_name = convert(fileutil.buildNewRootname(sciname, extn='_c1h.fits'))
+    try:
+        clobber = True
+        fimg = convertwaiveredfits.convertwaiveredfits(filename)
 
-    return newsciname
+        #check for the existence of a data quality file
+        _dqname = fileutil.buildNewRootname(filename, extn='_c1f.fits')
+        dqexists = os.path.exists(_dqname)
+        if convert_dq and dqexists:
+            try:
+                dqfile = convertwaiveredfits.convertwaiveredfits(_dqname)
+                dqfitsname = fileutil.buildNewRootname(_dqname, extn='_c1h.fits')
+            except Exception:
+                print("Could not read data quality file %s" % _dqname)
+        if writefits:
+            # User wants to make a FITS copy and update it
+            # using the filename they have provided
+            rname = fileutil.buildNewRootname(filename)
+            fitsname = fileutil.buildNewRootname(rname, extn='_c0h.fits')
 
+            # Write out GEIS image as multi-extension FITS.
+            fexists = os.path.exists(fitsname)
+            if (fexists and clobber) or not fexists:
+                print('Writing out WAIVERED as MEF to ', fitsname)
+                if ASTROPY_VER_GE13:
+                    fimg.writeto(fitsname, overwrite=clobber)
+                else:
+                    fimg.writeto(fitsname, clobber=clobber)
+                if dqexists:
+                    print('Writing out WAIVERED as MEF to ', dqfitsname)
+                    if ASTROPY_VER_GE13:
+                        dqfile.writeto(dqfitsname, overwrite=clobber)
+                    else:
+                        dqfile.writeto(dqfitsname, clobber=clobber)
+        # Now close input GEIS image, and open writable
+        # handle to output FITS image instead...
+        fimg.close()
+        del fimg
+
+        fimg = fits.open(fitsname, mode='update', memmap=False)
+
+        return fimg
+    except IOError:
+        print('Warning: File %s could not be found' % sciname)
+        return None
 
 
 def geis2mef(sciname, convert_dq=True):
@@ -425,23 +517,55 @@ def geis2mef(sciname, convert_dq=True):
     Writes out both files to disk.
     Returns the new name of the science image.
     """
+    clobber = True
+    mode = 'update'
+    memmap = True
+    # Input was specified as a GEIS image, but no FITS copy
+    # exists.  Read it in with 'readgeis' and make a copy
+    # then open the FITS copy...
+    try:
+        # Open as a GEIS image for reading only
+        fimg = readgeis.readgeis(sciname)
+    except Exception:
+        raise IOError("Could not open GEIS input: %s" % sciname)
 
-    def convert(file):
-        newfilename = fileutil.buildFITSName(file)
+    #check for the existence of a data quality file
+    _dqname = fileutil.buildNewRootname(sciname, extn='.c1h')
+    dqexists = os.path.exists(_dqname)
+    if dqexists:
         try:
-            newimage = fileutil.openImage(file,writefits=True,
-                fitsname=newfilename, clobber=True)
-            del newimage
-            return newfilename
-        except IOError:
-            print('Warning: File %s could not be found' % file)
-            return None
+            dqfile = readgeis.readgeis(_dqname)
+            dqfitsname = fileutil.buildFITSName(_dqname)
+        except Exception:
+            print("Could not read data quality file %s" % _dqname)
 
-    newsciname = convert(sciname)
-    if convert_dq:
-        dq_name = convert(sciname.split('.')[0] + '.c1h')
+    # Check to see if user wanted to update GEIS header.
+    # or write out a multi-extension FITS file and return a handle to it
+    # User wants to make a FITS copy and update it
+    # using the filename they have provided
+    fitsname = fileutil.buildFITSName(sciname)
 
-    return newsciname
+    # Write out GEIS image as multi-extension FITS.
+    fexists = os.path.exists(fitsname)
+    if (fexists and clobber) or not fexists:
+            print('Writing out GEIS as MEF to ', fitsname)
+            if ASTROPY_VER_GE13:
+                fimg.writeto(fitsname, overwrite=clobber)
+            else:
+                fimg.writeto(fitsname, clobber=clobber)
+            if dqexists:
+                print('Writing out GEIS as MEF to ', dqfitsname)
+                if ASTROPY_VER_GE13:
+                    dqfile.writeto(dqfitsname, overwrite=clobber)
+                else:
+                    dqfile.writeto(dqfitsname, clobber=clobber)
+    # Now close input GEIS image, and open writable
+    # handle to output FITS image instead...
+    fimg.close()
+    del fimg
+    fimg = fits.open(fitsname, mode=mode, memmap=memmap)
+
+    return fimg
 
 def countInput(input):
     files = parseinput.parseinput(input)
