@@ -7,6 +7,7 @@ import pytest
 from astropy.io.fits.tests import FitsTestCase
 
 from .. import fileutil as F
+from .. import stpyfits
 
 
 class TestIsFits(FitsTestCase):
@@ -14,7 +15,7 @@ class TestIsFits(FitsTestCase):
         self.data_dir = os.path.join(os.path.dirname(__file__), 'data')
         self.temp_dir = tempfile.mkdtemp(prefix='isfits-test-')
 
-    def test_isFits(self):
+    def test_isFits_fname(self):
         assert F.isFits(self.data('cdva2.fits')) == (True, 'simple')
         assert F.isFits(self.data('o4sp040b0_raw.fits')) == (True, 'mef')
         assert F.isFits(self.data('waivered.fits')) == (True, 'waiver')
@@ -26,3 +27,11 @@ class TestIsFits(FitsTestCase):
         # But if it has FITS extension, should raise error if nonexistent.
         with pytest.raises(IOError):
             F.isFits('isfits/no_such_file.fits')
+
+    def test_isFits_file_object(self):
+        with stpyfits.open(self.data('cdva2.fits')) as f:
+            assert F.isFits(f) == (True, 'simple')
+        with stpyfits.open(self.data('o4sp040b0_raw.fits')) as f:
+            assert F.isFits(f) == (True, 'mef')
+        with stpyfits.open(self.data('waivered.fits')) as f:
+            assert F.isFits(f) == (True, 'waiver')
